==> 0.1.1.tar.gz: ios/Classes/SwiftFlutterDocumentPickerDelegate.swift <==
//
//  SwiftFlutterDocumentPickerDelegate.swift
//  flutter_document_picker
//
//  Created by ts on 01/09/2018.
//

import Foundation
import UIKit

public class SwiftFlutterDocumentPickerDelegate: NSObject {
    fileprivate var flutterResult: FlutterResult?

    func pickDocument(_ params: FlutterDocumentPickerParams?, result: @escaping FlutterResult) {
        flutterResult = result

        guard let viewController = UIApplication.shared.keyWindow?.rootViewController else {
            result(FlutterError.init(code: "error",
                                     message: "Unable to get view controller!",
                                     details: nil)
            )
            return
        }

        var documentTypes = ["public.data"]

        if let customUtiType = params?.utiType {
            documentTypes = [customUtiType]
        }

        let documentPickerViewController = UIDocumentPickerViewController(documentTypes: documentTypes, in: .import)

        documentPickerViewController.delegate = self

        viewController.present(documentPickerViewController, animated: true, completion: nil)
    }
}

extension SwiftFlutterDocumentPickerDelegate: UIDocumentPickerDelegate {
    public func documentPicker(_ controller: UIDocumentPickerViewController, didPickDocumentAt url: URL) {
        // Create file URL to temporary folder
        var tempUrl = URL(fileURLWithPath: NSTemporaryDirectory())
        // Apend filename (name+extension) to URL
        tempUrl.appendPathComponent(url.lastPathComponent)
        do {
            // If file with same name exists remove it (replace file with new one)
            if FileManager.default.fileExists(atPath: tempUrl.path) {
                try FileManager.default.removeItem(atPath: tempUrl.path)
            }
            // Move file from app_id-Inbox to tmp/filename
            try FileManager.default.moveItem(atPath: url.path, toPath: tempUrl.path)
            flutterResult?(tempUrl.path)
        } catch {
            print(error.localizedDescription)
            flutterResult?(nil)
        }


    }

    public func documentPickerWasCancelled(_ controller: UIDocumentPickerViewController) {
        flutterResult?(nil)
    }
}

==> 1.0.0.tar.gz: ios/Classes/SwiftFlutterDocumentPickerDelegate.swift <==
//
//  SwiftFlutterDocumentPickerDelegate.swift
//  flutter_document_picker
//
//  Created by ts on 01/09/2018.
//

import Foundation
import UIKit

public class SwiftFlutterDocumentPickerDelegate: NSObject {
    fileprivate var flutterResult: FlutterResult?
    fileprivate var params: FlutterDocumentPickerParams?

    func pickDocument(_ params: FlutterDocumentPickerParams?, result: @escaping FlutterResult) {
        flutterResult = result
        self.params = params

        guard let viewController = UIApplication.shared.keyWindow?.rootViewController else {
            result(FlutterError.init(code: "error",
                                     message: "Unable to get view controller!",
                                     details: nil)
            )
            return
        }

        var documentTypes = ["public.data"]

        if let allowedUtiTypes = params?.allowedUtiTypes {
            if !allowedUtiTypes.isEmpty {
                documentTypes = allowedUtiTypes
            }
        }

        let documentPickerViewController = UIDocumentPickerViewController(documentTypes: documentTypes, in: .import)

        documentPickerViewController.delegate = self

        viewController.present(documentPickerViewController, animated: true, completion: nil)
    }
}

extension SwiftFlutterDocumentPickerDelegate: UIDocumentPickerDelegate {
    public func documentPicker(_ controller: UIDocumentPickerViewController, didPickDocumentAt url: URL) {
        let fileExtension = url.pathExtension

        if let allowedFileExtensions = params?.allowedFileExtensions {
            if !allowedFileExtensions.contains(where: { $0 == fileExtension }) {
                flutterResult?(FlutterError.init(code: "extension_mismatch",
                                                 message: "Picked file extension mismatch!",
                                                 details: fileExtension))
            }
        }

        // Create file URL to temporary folder
        var tempUrl = URL(fileURLWithPath: NSTemporaryDirectory())
        // Apend filename (name+extension) to URL
        tempUrl.appendPathComponent(url.lastPathComponent)
        do {
            // If file with same name exists remove it (replace file with new one)
            if FileManager.default.fileExists(atPath: tempUrl.path) {
                try FileManager.default.removeItem(atPath: tempUrl.path)
            }
            // Move file from app_id-Inbox to tmp/filename
            try FileManager.default.moveItem(atPath: url.path, toPath: tempUrl.path)
            flutterResult?(tempUrl.path)
        } catch {
            print(error.localizedDescription)
            flutterResult?(nil)
        }


    }

    public func documentPickerWasCancelled(_ controller: UIDocumentPickerViewController) {
        flutterResult?(nil)
    }
}
